Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1291)

Unified Diff: components/data_reduction_proxy/core/common/data_reduction_proxy_params.h

Issue 2019783002: Add histograms for requests that were fetched successfully (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed sclittle, asvitkine comments Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/data_reduction_proxy/core/common/data_reduction_proxy_params.h
diff --git a/components/data_reduction_proxy/core/common/data_reduction_proxy_params.h b/components/data_reduction_proxy/core/common/data_reduction_proxy_params.h
index 61f9bb105e2a2447cbee37e5cd619c5eb4f239e0..1cdc84ebd90d3bd65f6689825c2c083187a74342 100644
--- a/components/data_reduction_proxy/core/common/data_reduction_proxy_params.h
+++ b/components/data_reduction_proxy/core/common/data_reduction_proxy_params.h
@@ -144,14 +144,14 @@ const char* GetServerExperimentsFieldTrialName();
} // namespace params
// Contains information about a given proxy server. |proxies_for_http| contains
// the configured data reduction proxy servers. |is_fallback| notes whether the
// given proxy is a fallback.
struct DataReductionProxyTypeInfo {
DataReductionProxyTypeInfo();
DataReductionProxyTypeInfo(const DataReductionProxyTypeInfo& other);
~DataReductionProxyTypeInfo();
std::vector<net::ProxyServer> proxy_servers;
- bool is_fallback;
+ size_t proxy_index;
};
// Provides initialization parameters. Proxy origins, and the secure proxy
@@ -144,14 +144,14 @@ const char* GetServerExperimentsFieldTrialName();
} // namespace params
// Contains information about a given proxy server. |proxies_for_http| contains
-// the configured data reduction proxy servers. |is_fallback| notes whether the
-// given proxy is a fallback.
+// the configured data reduction proxy servers. |proxy_index| notes the index
+// of the data reduction proxy used in the list of all data reduction proxies.
struct DataReductionProxyTypeInfo {
DataReductionProxyTypeInfo();

Powered by Google App Engine
This is Rietveld 408576698